"use client";
import React, { useState, useEffect } from "react";
import Image from "next/image";
import { useTranslations } from "next-intl";
import { getWithToken, postApiFormDataToken, postWithToken,decryptText } from "@/Helper/common";
import './profile.css'
import Link from "next/link";
import DashboardIcon from '@mui/icons-material/Dashboard';
import PlanList from "./components/table";
import { Progress } from "@/components/ui/progress";
import { WhatsappShareButton, WhatsappIcon } from 'react-share';
import {
  Card,
  CardContent,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";
import { Badge } from "@/components/ui/badge";
import { Phone, User, Wallet } from "lucide-react";
import { DocumentScannerRounded, Email, EmailOutlined, PriceCheck } from "@mui/icons-material";
import { FileUploader } from "react-drag-drop-files";
import toast, { Toaster } from "react-hot-toast";
import { RadioGroup, RadioGroupItem } from "@/components/ui/radio-group";
import { Button } from "@/components/ui/button";
import { ClipLoader } from "react-spinners";
import AdminList from "../members/action-history/[id]/admin-list-tab";


const Home = () => {

  const getBaseUrl = () => {
    const { protocol, hostname, port } = window.location;
    return `${protocol}//${hostname}${port ? `:${port}` : ''}`;
  };

  const baseUrl = getBaseUrl();
  const lang = useTranslations("Profile");
  const Merchant_Onboarding = useTranslations("Merchant_Onboarding");
  const IndexLang = useTranslations("Index");
  const [kycDetailsData, setKycDetailsData] = useState([]);
  const [userDetailsData, setUserDetailsData] = useState([]);
  const [loading, setLoading] = useState(false)
  const [email, setEmail] = useState("");
  const [image, setImage] = useState("");
  const [registerAsARetailer, setRegisterAsARetailer] = useState(false);
  const [registerAsAMDDT, setRegisterAsAMDDT] = useState(false);
  const [loadingRegister, setLoadingRegister] = useState(false);
  const [loadingRegisterMD, setLoadingRegisterMD] = useState(false);
  const [designationType, setDesignationType] = useState("");
  const [mdDtType, setMdDtType] = useState("");

  var apiCall = true;
  const fetchKycData = async () => {
    try {

      setLoading(true);

      if (apiCall) {

        apiCall = false;

        const apiResData = await getWithToken("get-kyc-details");
        if (apiResData.error === false) {
          setKycDetailsData(apiResData.data);
          setUserDetailsData(apiResData.userData);
          setEmail(apiResData.userData?.email);
          setImage(apiResData.userData?.image);
          setDesignationType(apiResData?.userData?.designation_id);

          if (apiResData.userData?.allow_as_a_md == 'Yes') {
            setMdDtType('Master Distributor');
          } else if (apiResData.userData?.allow_as_a_dt == 'Yes') {
            setMdDtType('Distributor');
          }
        }

        setLoading(false);
      }
    } catch (error) {
      console.error("Error fetching:", error);
      setLoading(false);
    }
  };

  useEffect(() => {
    fetchKycData();
  }, []);

  const handleImageChange = (event) => {

    if (event.target.files && event.target.files[0]) {
      setImage(URL.createObjectURL(event.target.files[0]));

      handleUpload(event.target.files[0]);
    }
  };

  const handleUpload = async (image) => {

    const formData = new FormData();
    formData.append('attachment_files', image);

    try {

      toast.dismiss();
      const apiRes = await postApiFormDataToken(`profile/add`, formData);

      // console.log(apiRes);
      if (apiRes.error) {
        toast.error(apiRes.message, {
          position: "bottom-center",
          style: {
            borderRadius: "10px",
            background: "#333",
            color: "#fff",
          },
        });
      } else {
        toast.success(apiRes.message, {
          position: "bottom-center",
          style: {
            borderRadius: "10px",
            background: "#333",
            color: "#fff",
          },
        });

      }

    } catch (error) {
      console.error('Error uploading image:', error);
    }
  };


  const RegisterAsARetailerConfirm = (value) => {
    if (value === 'true') {
      const isConfirmed = window.confirm(
        "Are you sure you want to register as Retailer on Your Profile?"
      );

      if (isConfirmed) {
        setRegisterAsARetailer(true); // Set to true if confirmed
      } else {
        setRegisterAsARetailer(false); // Revert to false if not confirmed
      }
    } else {
      setRegisterAsARetailer(false); // Directly set to false for "No"
    }
  };

  const RegisterAsAMDDtConfirm = (value) => {
    if (value === 'true') {
      const isConfirmed = window.confirm(
        `Are you sure you want to register as ${mdDtType} on Your Profile?`
      );

      if (isConfirmed) {
        setRegisterAsAMDDT(true); // Set to true if confirmed
      } else {
        setRegisterAsAMDDT(false); // Revert to false if not confirmed
      }
    } else {
      setRegisterAsAMDDT(false); // Directly set to false for "No"
    }
  };


  const registeredAsARetailerSubmit = async () => {

    setLoadingRegister(true);

    try {
      toast.dismiss();
      const apiRes = await getWithToken(`registered-as-a-retailer`);

      // console.log(apiRes);
      if (apiRes.error) {
        toast.error(apiRes.message, {
          position: "bottom-center",
          style: {
            borderRadius: "10px",
            background: "#333",
            color: "#fff",
          },
        });
      } else {
        toast.success(apiRes.message, {
          position: "bottom-center",
          style: {
            borderRadius: "10px",
            background: "#333",
            color: "#fff",
          },
        });
        fetchKycData();


      }
    } catch (error) {
      console.error("Error uploading image:", error);
    } finally {
      setLoadingRegister(false);
    }
  };

  const registeredAsAMDDTSubmit = async () => {

    setLoadingRegisterMD(true);

    try {
      toast.dismiss();
      const apiRes = await getWithToken(`registered-as-a-md-dt`);

      // console.log(apiRes);
      if (apiRes.error) {
        toast.error(apiRes.message, {
          position: "bottom-center",
          style: {
            borderRadius: "10px",
            background: "#333",
            color: "#fff",
          },
        });
      } else {
        toast.success(apiRes.message, {
          position: "bottom-center",
          style: {
            borderRadius: "10px",
            background: "#333",
            color: "#fff",
          },
        });
        fetchKycData();


      }
    } catch (error) {
      console.error("Error uploading image:", error);
    } finally {
      setLoadingRegisterMD(false);
    }
  };


  return (

    loading ?
      <div className="space-y-6 ml-5">
        <div className="flex flex-col items-center text-center">
          <div className="col-span-12 lg:col-span-12 mx-auto">
            <ClipLoader loading={true} size={50} />
          </div>
        </div>
      </div>
      :
      <>
        <div className="rounded-md bg-card text-card-foreground shadow-sm rounded-t-2xl mt-0">
          <div className="p-0" style={{
            backgroundImage: `url('../img/USER_PANEL.png')`, backgroundRepeat: 'no-repeat',
            backgroundSize: '100% 258px'
          }}>

            <div
              className="relative h-[150px] lg:h-[200px] rounded-t-2xl w-full object-cover bg-no-repeat"

            >

            </div>
            <div className="flex flex-wrap justify-end gap-4 lg:gap-8 pt-7 lg:pt-5 pb-4 px-6">
              {
                designationType == 1 ?

                  <Link
                    className="text-black text-sm font-semibold text-default-500  hover:text-primary relative lg:before:absolute before:-bottom-4 before:left-0 before:w-full lg:before:h-[1px] before:bg-transparent"
                    href="/admin/update-basic-details"
                  >
                    <span style={{ color: "black" }}>{lang('Update_Basic_Details')}</span>
                  </Link>

                  : null


              }

              <Link
                className="text-black text-sm font-semibold text-default-500  hover:text-primary relative lg:before:absolute before:-bottom-4 before:left-0 before:w-full lg:before:h-[1px] before:bg-transparent"
                href="/admin/update-mpin"
              >
                <span style={{ color: "black" }}>{lang("Update M-Pin")}</span>
              </Link>
              <Link
                className="text-sm font-semibold text-default-500 hover:text-primary relative lg:before:absolute before:-bottom-4 before:left-0 before:w-full lg:before:h-[1px] before:bg-transparent"
                href="/admin/update-password"
              >
                <span style={{ color: "black" }}>{lang("Update Password")}</span>
              </Link>

              <Link
                className="text-sm font-semibold text-default-500 hover:text-primary relative lg:before:absolute before:-bottom-4 before:left-0 before:w-full lg:before:h-[1px] before:bg-transparent"
                href="/admin/ticket/create"
              >
                <span style={{ color: "black" }}>{lang("Create Ticket")}</span>
              </Link>
            </div>
          </div>
        </div>
        <div className=" grid grid-cols-12 gap-6 mt-5">
          <div className="col-span-12 lg:col-span-4 space-y-6">

            {/* for RT to MD */}
            <div className="rounded-md bg-card text-card-foreground shadow-sm">
              {
                kycDetailsData && kycDetailsData?.kyc_status == 'Approved' && kycDetailsData?.register_md_dt == 'No' && kycDetailsData?.allowDTMTConvertIntoRt ?

                  <>

                    {
                      (designationType == "5") ?
                        <>
                          <div className="flex flex-col space-y-1.5 px-4 py-4 border-b border-border border-none mb-0">
                            <h3 className="text-lg font-medium text-default-800">
                              You want to work as {mdDtType}
                            </h3>
                          </div>
                          <div className="p-6 pt-0 px-4 mb-4">

                            <RadioGroup
                              className="mb-10 gap-5 md:gap-36 mt-5"
                              value={registerAsAMDDT ? 'true' : 'false'} // Control value with state
                              onValueChange={RegisterAsAMDDtConfirm} // Handle value change
                            >
                              <RadioGroupItem value="true" id="transfer">
                                Yes
                              </RadioGroupItem>

                              <RadioGroupItem value="false" id="beneficiary">
                                No
                              </RadioGroupItem>
                            </RadioGroup>
                            {
                              registerAsAMDDT == true ?
                                <>
                                  <Button
                                    size="xs"
                                    variant="outline"
                                    color="success"
                                    type="button"
                                    className="mb-5"
                                    onClick={() => registeredAsAMDDTSubmit()}
                                    sx={{ mr: 1 }}
                                    disabled={loadingRegisterMD}
                                  >
                                    Registered
                                    {loadingRegisterMD ? (
                                      <svg
                                        xmlns="http://www.w3.org/2000/svg"
                                        width="2em"
                                        height="2em"
                                        viewBox="0 0 24 24"
                                      >
                                        <g
                                          fill="none"
                                          stroke="currentColor"
                                          stroke-linecap="round"
                                          stroke-width="2"
                                        >
                                          <path
                                            stroke-dasharray="60"
                                            stroke-dashoffset="60"
                                            stroke-opacity="0.3"
                                            d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                                          >
                                            <animate
                                              fill="freeze"
                                              attributeName="stroke-dashoffset"
                                              dur="1.3s"
                                              values="60;0"
                                            />
                                          </path>
                                          <path
                                            stroke-dasharray="15"
                                            stroke-dashoffset="15"
                                            d="M12 3C16.9706 3 21 7.02944 21 12"
                                          >
                                            <animate
                                              fill="freeze"
                                              attributeName="stroke-dashoffset"
                                              dur="0.3s"
                                              values="15;0"
                                            />
                                            <animateTransform
                                              attributeName="transform"
                                              dur="1.5s"
                                              repeatCount="indefinite"
                                              type="rotate"
                                              values="0 12 12;360 12 12"
                                            />
                                          </path>
                                        </g>
                                      </svg>
                                    ) : null}
                                  </Button>

                                </>
                                : null
                            }
                            <p style={{ color: 'red' }}>Note : If you select Yes, we will create a new profile for you as a {mdDtType}. Please choose carefully. </p>

                          </div>
                        </>

                        : null
                    }
                  </>

                  : null
              }
            </div>

            {/* for MD to RT */}
            <div className="rounded-md bg-card text-card-foreground shadow-sm">
              {
                kycDetailsData && kycDetailsData?.kyc_status == 'Approved' && kycDetailsData?.register_retailer == 'No' && kycDetailsData?.allowRTConvertIntoMTDT ?

                  <>

                    {
                      (designationType == "3" || designationType == "4") ?

                        <>
                          <div className="flex flex-col space-y-1.5 px-4 py-4 border-b border-border border-none mb-0">
                            <h3 className="text-lg font-medium text-default-800">
                              You want to work as Retailer
                            </h3>
                          </div>
                          <div className="p-6 pt-0 px-4 mb-4">

                            <>

                              <RadioGroup
                                className="mb-10 gap-5 md:gap-36 mt-5"
                                value={registerAsARetailer ? 'true' : 'false'} // Control value with state
                                onValueChange={RegisterAsARetailerConfirm} // Handle value change
                              >
                                <RadioGroupItem value="true" id="transfer">
                                  Yes
                                </RadioGroupItem>

                                <RadioGroupItem value="false" id="beneficiary">
                                  No
                                </RadioGroupItem>
                              </RadioGroup>
                              {
                                registerAsARetailer == true ?
                                  <>
                                    <Button
                                      size="xs"
                                      variant="outline"
                                      color="success"
                                      type="button"
                                      className="mb-5"
                                      onClick={() => registeredAsARetailerSubmit()}
                                      sx={{ mr: 1 }}
                                      disabled={loadingRegister}
                                    >
                                      Registered
                                      {loadingRegister ? (
                                        <svg
                                          xmlns="http://www.w3.org/2000/svg"
                                          width="2em"
                                          height="2em"
                                          viewBox="0 0 24 24"
                                        >
                                          <g
                                            fill="none"
                                            stroke="currentColor"
                                            stroke-linecap="round"
                                            stroke-width="2"
                                          >
                                            <path
                                              stroke-dasharray="60"
                                              stroke-dashoffset="60"
                                              stroke-opacity="0.3"
                                              d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                                            >
                                              <animate
                                                fill="freeze"
                                                attributeName="stroke-dashoffset"
                                                dur="1.3s"
                                                values="60;0"
                                              />
                                            </path>
                                            <path
                                              stroke-dasharray="15"
                                              stroke-dashoffset="15"
                                              d="M12 3C16.9706 3 21 7.02944 21 12"
                                            >
                                              <animate
                                                fill="freeze"
                                                attributeName="stroke-dashoffset"
                                                dur="0.3s"
                                                values="15;0"
                                              />
                                              <animateTransform
                                                attributeName="transform"
                                                dur="1.5s"
                                                repeatCount="indefinite"
                                                type="rotate"
                                                values="0 12 12;360 12 12"
                                              />
                                            </path>
                                          </g>
                                        </svg>
                                      ) : null}
                                    </Button>

                                  </>
                                  : null
                              }
                              <p style={{ color: 'red' }}>Note : If you select Yes, we will create a new profile for you as a Retailer. Please choose carefully. </p>

                            </>

                          </div>
                        </>

                        : null
                    }


                  </>

                  : null
              }
            </div>

            <div className="rounded-md bg-card text-card-foreground shadow-sm">
              <div className="flex flex-col space-y-1.5 px-4 py-4 border-b border-border border-none mb-0">
                <h3 className="text-lg font-medium text-default-800">
                  {lang("KYC Status")}
                </h3>
              </div>
              <div className="p-6 pt-0 px-4 mb-4">
                {
                  kycDetailsData && kycDetailsData?.kyc_status == 'Approved' ?

                    <>

                      <label className="peer-disabled:cursor-not-allowed peer-disabled:opacity-50 inline-block text-sm font-medium text-default-700 mb-5">
                        100% {lang("Complete")}
                      </label>

                      <Progress value={100} />
                    </>

                    : kycDetailsData && kycDetailsData?.kyc_status == 'Pending' ?

                      <>

                        <div
                          style={{ height: "50px" }}
                          className="flex  items-center bg-warning  w-full"
                        >
                          <p className=" text-white font-bold text-lg mx-5">
                            {lang("Complete Your KYC")}&nbsp;&nbsp;
                            <Link
                              href="/admin/kyc-update"
                              prefetch={true}
                              class="underline"
                            >
                              {lang("Click here")}
                            </Link>{" "}

                          </p>
                        </div>
                      </>

                      :

                      <Badge
                        variant="soft"
                        color={
                          kycDetailsData?.kyc_status === "Pending"
                            ? "warning"
                            : kycDetailsData?.kyc_status === "Update"
                              ? "info"
                              : kycDetailsData?.kyc_status === "Approved"
                                ? "success"
                                : "destructive"
                        }
                        className="capitalize"
                      >
                        {kycDetailsData?.kyc_status}
                      </Badge>
                }


              </div>
            </div>
            <div className="rounded-md bg-card text-card-foreground shadow-sm">
              <div className="flex flex-col space-y-1.5 px-4 py-4 border-b border-border border-none mb-0">

              </div>
              <div className="p-6 pt-0 px-4 mb-4">
                <>
                  <div
                    style={{ height: "50px" }}
                    className="flex  items-center bg-primary  w-full"
                  >
                    <p className=" text-white font-bold text-lg mx-5 flex justify-between  align-center gap-5">
                      {lang("click_here_to_refer")}
                      <WhatsappShareButton url={`${baseUrl}/referral/${userDetailsData.unique_id}`} separator=":: ">
                        <WhatsappIcon size={32} round />
                      </WhatsappShareButton>
                    </p>
                  </div>
                </>



              </div>
            </div>

            <div className="rounded-md bg-card text-card-foreground shadow-sm">
              <div className="p-6 flex flex-col items-center">
                <div className="w-[124px] h-[124px] relative rounded-full">
                  {image ? (
                    <img
                      src={image}
                      loading="lazy"
                      width={300}
                      height={300}
                      className="w-full h-full object-cover rounded-full"
                      style={{ color: "transparent" }}
                    />
                  ) : (
                    // <img src={resultData?.image} width="165px" />

                    <img
                      alt="avatar"
                      loading="lazy"
                      width={300}
                      height={300}
                      decoding="async"
                      data-nimg={1}
                      className="w-full h-full object-cover rounded-full"
                      src="https://png.pngtree.com/png-vector/20231019/ourmid/pngtree-user-profile-avatar-png-image_10211467.png"
                      style={{ color: "transparent" }}
                    />
                  )}

                  <label
                    className="peer-disabled:cursor-not-allowed peer-disabled:opacity-50 inline-flex items-center justify-center text-sm font-semibold ring-offset-background transition-colors focus-visible:outline-none focus-visible:ring-0 disabled:opacity-50 whitespace-nowrap disabled:pointer-events-none bg-primary text-primary-foreground hover:bg-primary/80 h-8 w-8 rounded-full cursor-pointer absolute bottom-0 right-0"
                    htmlFor="avatar"
                  >
                    <svg
                      xmlns="http://www.w3.org/2000/svg"
                      xmlnsXlink="http://www.w3.org/1999/xlink"
                      aria-hidden="true"
                      role="img"
                      className="w-5 h-5 text-primary-foreground iconify iconify--heroicons"
                      width="1em"
                      height="1em"
                      viewBox="0 0 24 24"
                    >
                      <path
                        fill="none"
                        stroke="currentColor"
                        strokeLinecap="round"
                        strokeLinejoin="round"
                        strokeWidth="1.5"
                        d="m16.862 4.487l1.687-1.688a1.875 1.875 0 1 1 2.652 2.652L10.582 16.07a4.5 4.5 0 0 1-1.897 1.13L6 18l.8-2.685a4.5 4.5 0 0 1 1.13-1.897zm0 0L19.5 7.125M18 14v4.75A2.25 2.25 0 0 1 15.75 21H5.25A2.25 2.25 0 0 1 3 18.75V8.25A2.25 2.25 0 0 1 5.25 6H10"
                      />
                    </svg>
                  </label>
                  <div className="flex-1 w-full">
                    <input
                      className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9 hidden"
                      id="avatar"
                      type="file"
                      onChange={handleImageChange}
                    />

                  </div>
                </div>
                <div className="mt-4 text-xl font-semibold text-default-900 text-center">
                  {userDetailsData?.first_name} {userDetailsData?.last_name} <br />
                  {userDetailsData?.unique_id}
                </div>
                <div className="mt-1.5 text-sm font-medium text-default-500">
                  {/* Data Analytics */}
                </div>
              </div>
            </div>

            <div className="rounded-md bg-card text-card-foreground shadow-sm">
              <div className="flex flex-col space-y-1.5 px-4 py-4 border-b border-border border-none mb-0">
                <h3 className="text-lg font-medium text-default-800">{lang("User Information")}</h3>
              </div>
              <div className="p-6 pt-0 px-4">
                <p className="text-sm text-default-600">

                </p>
                <ul className="mt-2 space-y-4">
                  {
                    userDetailsData.designation_id != '2' ?

                      <li className="flex items-center">
                        <div className="flex-none  2xl:w-40 flex items-center gap-1.5">
                          <span>
                            <Wallet />
                          </span>
                          <span className="text-sm font-medium text-default-800">
                            {lang("Use Wallet")}:
                          </span>
                        </div>
                        <div className="flex-1 text-sm text-default-700">
                          ₹{userDetailsData?.wallet}

                        </div>
                      </li>

                      : null
                  }

                  <li className="flex items-center">
                    <div className="flex-none  2xl:w-40 flex items-center gap-1.5">
                      <span>
                        <User />
                      </span>
                      <span className="text-sm font-medium text-default-800">
                        {lang("Use Id")}:
                      </span>
                    </div>
                    <div className="flex-1 text-sm text-default-700">
                      {userDetailsData?.unique_id}

                    </div>
                  </li>
                  <li className="flex items-center">
                    <div className="flex-none  2xl:w-40 flex items-center gap-1.5">
                      <span>
                        <PriceCheck />
                      </span>
                      <span className="text-sm font-medium text-default-800">
                      {lang('Active_Plan')}:
                      </span>
                    </div>
                    <div className="flex-1 text-sm text-default-700">
                      {userDetailsData?.plan}

                    </div>
                  </li>
                  <li className="flex items-center">
                    <div className="flex-none  2xl:w-40 flex items-center gap-1.5">
                      <EmailOutlined />
                      <span className="text-sm font-medium text-default-800">
                        {lang("Email Id")}:
                      </span>
                    </div>
                    <div className="flex-1 text-sm text-default-700"> {userDetailsData?.email}
                    </div>
                  </li>
                  <li className="flex items-center">
                    <div className="flex-none  2xl:w-40 flex items-center gap-1.5">
                      <span>
                        <Phone />
                      </span>
                      <span className="text-sm font-medium text-default-800">
                        {lang("Mobile No")}:
                      </span>
                    </div>
                    <div className="flex-1 text-sm text-default-700">
                      +91{userDetailsData?.phone ? userDetailsData?.phone : "91 xxxxxxxx"}

                    </div>
                  </li>
                  <li className="flex items-center">
                    <div className="flex-none  2xl:w-40 flex items-center gap-1.5">
                      <span>
                        <DocumentScannerRounded />
                      </span>
                      <span className="text-sm font-medium text-default-800">
                      {Merchant_Onboarding('Aadhar Number')} :
                      </span>
                    </div>
                    <div className="flex-1 text-sm text-default-700">
                      {decryptText(kycDetailsData?.aadhar_number) ? decryptText(kycDetailsData?.aadhar_number) : "xxxxxxxxXXXX"}

                    </div>
                  </li>
                  <li className="flex items-center">
                    <div className="flex-none  2xl:w-40 flex items-center gap-1.5">
                      <span>
                        <DocumentScannerRounded />
                      </span>
                      <span className="text-sm font-medium text-default-800">
                      {Merchant_Onboarding('Pan Number')} :
                      </span>
                    </div>
                    <div className="flex-1 text-sm text-default-700">
                      {decryptText(kycDetailsData?.pancard_number) ? decryptText(kycDetailsData?.pancard_number) : "xxxxxxxx"}

                    </div>
                  </li>
                  <li className="flex items-center">
                    <div className="flex-none  2xl:w-40 flex items-center gap-1.5">
                      <span>
                        <DocumentScannerRounded />
                      </span>
                      <span className="text-sm font-medium text-default-800">
                      {IndexLang('GST')}:
                      </span>
                    </div>
                    <div className="flex-1 text-sm text-default-700">
                      {kycDetailsData?.gst == 'Yes' ? kycDetailsData?.gst_number : "No"}

                    </div>
                  </li>
                  {
                    designationType != '1' ?

                    <li className="flex items-center">
                      <div className="flex-none  2xl:w-40 flex items-center gap-1.5">
                        <Button ><a href="/admin/plan-list/view">{lang("Upgrade_To_Pro")}</a></Button>

                      </div>

                    </li>

                    : null
                  }
                  


                </ul>

              </div>
            </div>



          </div>
          <div className="col-span-12 lg:col-span-8 space-y-6">
            {/* <PlanList/> */}


            {/* <Card>
       
        <CardContent className="p-0">
          <div className="px-4 space-y-4 gap-2 lg:space-y-0 lg:grid lg:grid-cols-1 gap-6 mx-auto ">
            <div className="col-span-2 mb-5">
              <PlanList />
            </div>
          </div>
        </CardContent>
      </Card > */}


            <Card>
              <CardHeader>
                <CardTitle>
                  <div style={{ display: "flex", justifyContent: "space-between" }}>
                    {lang("User_Action_History")}

                  </div>
                </CardTitle>
              </CardHeader>
              <CardContent className="p-0">
                <div className="px-4 space-y-4 gap-2 lg:space-y-0 lg:grid lg:grid-cols-1 gap-6 mx-auto ">
                  <div className="col-span-2 mb-5">
                  <AdminList userId={userDetailsData?.id} showType="self"/>
                  </div>
                </div>
              </CardContent>
            </Card >


          </div>
        </div>

      </>


  );
};

export default Home;
